@@ -1,8 +1,10 @@
+from http import HTTPStatus
 from typing import Any, Dict, List, Optional, Union
 
 import httpx
 
-from ...client import Client
+from ... import errors
+from ...client import AuthenticatedClient, Client
 from ...models.list_apps_response_200_item import ListAppsResponse200Item
 from ...types import UNSET, Response, Unset
 
@@ -10,7 +12,6 @@ from ...types import UNSET, Response, Unset
 def _get_kwargs(
     workspace: str,
     *,
-    client: Client,
     page: Union[Unset, None, int] = UNSET,
     per_page: Union[Unset, None, int] = UNSET,
     order_desc: Union[Unset, None, bool] = UNSET,
@@ -19,10 +20,7 @@ def _get_kwargs(
     path_exact: Union[Unset, None, str] = UNSET,
     starred_only: Union[Unset, None, bool] = UNSET,
 ) -> Dict[str, Any]:
-    url = "{}/w/{workspace}/apps/list".format(client.base_url, workspace=workspace)
-
-    headers: Dict[str, str] = client.get_headers()
-    cookies: Dict[str, Any] = client.get_cookies()
+    pass
 
     params: Dict[str, Any] = {}
     params["page"] = page
@@ -43,16 +41,17 @@ def _get_kwargs(
 
     return {
         "method": "get",
-        "url": url,
-        "headers": headers,
-        "cookies": cookies,
-        "timeout": client.get_timeout(),
+        "url": "/w/{workspace}/apps/list".format(
+            workspace=workspace,
+        ),
         "params": params,
     }
 
 
-def _parse_response(*, response: httpx.Response) -> Optional[List[ListAppsResponse200Item]]:
-    if response.status_code == 200:
+def _parse_response(
+    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
+) -> Optional[List["ListAppsResponse200Item"]]:
+    if response.status_code == HTTPStatus.OK:
         response_200 = []
         _response_200 = response.json()
         for response_200_item_data in _response_200:
@@ -61,22 +60,27 @@ def _parse_response(*, response: httpx.Response) -> Optional[List[ListAppsRespon
             response_200.append(response_200_item)
 
         return response_200
-    return None
+    if client.raise_on_unexpected_status:
+        raise errors.UnexpectedStatus(response.status_code, response.content)
+    else:
+        return None
 
 
-def _build_response(*, response: httpx.Response) -> Response[List[ListAppsResponse200Item]]:
+def _build_response(
+    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
+) -> Response[List["ListAppsResponse200Item"]]:
     return Response(
-        status_code=response.status_code,
+        status_code=HTTPStatus(response.status_code),
         content=response.content,
         headers=response.headers,
-        parsed=_parse_response(response=response),
+        parsed=_parse_response(client=client, response=response),
     )
 
 
 def sync_detailed(
     workspace: str,
     *,
-    client: Client,
+    client: Union[AuthenticatedClient, Client],
     page: Union[Unset, None, int] = UNSET,
     per_page: Union[Unset, None, int] = UNSET,
     order_desc: Union[Unset, None, bool] = UNSET,
@@ -84,8 +88,8 @@ def sync_detailed(
     path_start: Union[Unset, None, str] = UNSET,
     path_exact: Union[Unset, None, str] = UNSET,
     starred_only: Union[Unset, None, bool] = UNSET,
-) -> Response[List[ListAppsResponse200Item]]:
-    """list all available apps
+) -> Response[List["ListAppsResponse200Item"]]:
+    """list all apps
 
     Args:
         workspace (str):
@@ -97,13 +101,16 @@ def sync_detailed(
         path_exact (Union[Unset, None, str]):
         starred_only (Union[Unset, None, bool]):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
-        Response[List[ListAppsResponse200Item]]
+        Response[List['ListAppsResponse200Item']]
     """
 
     kwargs = _get_kwargs(
         workspace=workspace,
-        client=client,
         page=page,
         per_page=per_page,
         order_desc=order_desc,
@@ -113,18 +120,17 @@ def sync_detailed(
         starred_only=starred_only,
     )
 
-    response = httpx.request(
-        verify=client.verify_ssl,
+    response = client.get_httpx_client().request(
         **kwargs,
     )
 
-    return _build_response(response=response)
+    return _build_response(client=client, response=response)
 
 
 def sync(
     workspace: str,
     *,
-    client: Client,
+    client: Union[AuthenticatedClient, Client],
     page: Union[Unset, None, int] = UNSET,
     per_page: Union[Unset, None, int] = UNSET,
     order_desc: Union[Unset, None, bool] = UNSET,
@@ -132,8 +138,8 @@ def sync(
     path_start: Union[Unset, None, str] = UNSET,
     path_exact: Union[Unset, None, str] = UNSET,
     starred_only: Union[Unset, None, bool] = UNSET,
-) -> Optional[List[ListAppsResponse200Item]]:
-    """list all available apps
+) -> Optional[List["ListAppsResponse200Item"]]:
+    """list all apps
 
     Args:
         workspace (str):
@@ -145,8 +151,12 @@ def sync(
         path_exact (Union[Unset, None, str]):
         starred_only (Union[Unset, None, bool]):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
-        Response[List[ListAppsResponse200Item]]
+        List['ListAppsResponse200Item']
     """
 
     return sync_detailed(
@@ -165,7 +175,7 @@ def sync(
 async def asyncio_detailed(
     workspace: str,
     *,
-    client: Client,
+    client: Union[AuthenticatedClient, Client],
     page: Union[Unset, None, int] = UNSET,
     per_page: Union[Unset, None, int] = UNSET,
     order_desc: Union[Unset, None, bool] = UNSET,
@@ -173,8 +183,8 @@ async def asyncio_detailed(
     path_start: Union[Unset, None, str] = UNSET,
     path_exact: Union[Unset, None, str] = UNSET,
     starred_only: Union[Unset, None, bool] = UNSET,
-) -> Response[List[ListAppsResponse200Item]]:
-    """list all available apps
+) -> Response[List["ListAppsResponse200Item"]]:
+    """list all apps
 
     Args:
         workspace (str):
@@ -186,13 +196,16 @@ async def asyncio_detailed(
         path_exact (Union[Unset, None, str]):
         starred_only (Union[Unset, None, bool]):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
-        Response[List[ListAppsResponse200Item]]
+        Response[List['ListAppsResponse200Item']]
     """
 
     kwargs = _get_kwargs(
         workspace=workspace,
-        client=client,
         page=page,
         per_page=per_page,
         order_desc=order_desc,
@@ -202,16 +215,15 @@ async def asyncio_detailed(
         starred_only=starred_only,
     )
 
-    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
-        response = await _client.request(**kwargs)
+    response = await client.get_async_httpx_client().request(**kwargs)
 
-    return _build_response(response=response)
+    return _build_response(client=client, response=response)
 
 
 async def asyncio(
     workspace: str,
     *,
-    client: Client,
+    client: Union[AuthenticatedClient, Client],
     page: Union[Unset, None, int] = UNSET,
     per_page: Union[Unset, None, int] = UNSET,
     order_desc: Union[Unset, None, bool] = UNSET,
@@ -219,8 +231,8 @@ async def asyncio(
     path_start: Union[Unset, None, str] = UNSET,
     path_exact: Union[Unset, None, str] = UNSET,
     starred_only: Union[Unset, None, bool] = UNSET,
-) -> Optional[List[ListAppsResponse200Item]]:
-    """list all available apps
+) -> Optional[List["ListAppsResponse200Item"]]:
+    """list all apps
 
     Args:
         workspace (str):
@@ -232,8 +244,12 @@ async def asyncio(
         path_exact (Union[Unset, None, str]):
         starred_only (Union[Unset, None, bool]):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
-        Response[List[ListAppsResponse200Item]]
+        List['ListAppsResponse200Item']
     """
 
     return (
