@@ -1,21 +1,19 @@
+from http import HTTPStatus
 from typing import Any, Dict, List, Optional, Union, cast
 
 import httpx
 
-from ...client import Client
+from ... import errors
+from ...client import AuthenticatedClient, Client
 from ...types import UNSET, Response, Unset
 
 
 def _get_kwargs(
     workspace: str,
     *,
-    client: Client,
     only_member_of: Union[Unset, None, bool] = UNSET,
 ) -> Dict[str, Any]:
-    url = "{}/w/{workspace}/groups/listnames".format(client.base_url, workspace=workspace)
-
-    headers: Dict[str, str] = client.get_headers()
-    cookies: Dict[str, Any] = client.get_cookies()
+    pass
 
     params: Dict[str, Any] = {}
     params["only_member_of"] = only_member_of
@@ -24,35 +22,37 @@ def _get_kwargs(
 
     return {
         "method": "get",
-        "url": url,
-        "headers": headers,
-        "cookies": cookies,
-        "timeout": client.get_timeout(),
+        "url": "/w/{workspace}/groups/listnames".format(
+            workspace=workspace,
+        ),
         "params": params,
     }
 
 
-def _parse_response(*, response: httpx.Response) -> Optional[List[str]]:
-    if response.status_code == 200:
+def _parse_response(*, client: Union[AuthenticatedClient, Client], response: httpx.Response) -> Optional[List[str]]:
+    if response.status_code == HTTPStatus.OK:
         response_200 = cast(List[str], response.json())
 
         return response_200
-    return None
+    if client.raise_on_unexpected_status:
+        raise errors.UnexpectedStatus(response.status_code, response.content)
+    else:
+        return None
 
 
-def _build_response(*, response: httpx.Response) -> Response[List[str]]:
+def _build_response(*, client: Union[AuthenticatedClient, Client], response: httpx.Response) -> Response[List[str]]:
     return Response(
-        status_code=response.status_code,
+        status_code=HTTPStatus(response.status_code),
         content=response.content,
         headers=response.headers,
-        parsed=_parse_response(response=response),
+        parsed=_parse_response(client=client, response=response),
     )
 
 
 def sync_detailed(
     workspace: str,
     *,
-    client: Client,
+    client: Union[AuthenticatedClient, Client],
     only_member_of: Union[Unset, None, bool] = UNSET,
 ) -> Response[List[str]]:
     """list group names
@@ -61,28 +61,30 @@ def sync_detailed(
         workspace (str):
         only_member_of (Union[Unset, None, bool]):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
         Response[List[str]]
     """
 
     kwargs = _get_kwargs(
         workspace=workspace,
-        client=client,
         only_member_of=only_member_of,
     )
 
-    response = httpx.request(
-        verify=client.verify_ssl,
+    response = client.get_httpx_client().request(
         **kwargs,
     )
 
-    return _build_response(response=response)
+    return _build_response(client=client, response=response)
 
 
 def sync(
     workspace: str,
     *,
-    client: Client,
+    client: Union[AuthenticatedClient, Client],
     only_member_of: Union[Unset, None, bool] = UNSET,
 ) -> Optional[List[str]]:
     """list group names
@@ -91,8 +93,12 @@ def sync(
         workspace (str):
         only_member_of (Union[Unset, None, bool]):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
-        Response[List[str]]
+        List[str]
     """
 
     return sync_detailed(
@@ -105,7 +111,7 @@ def sync(
 async def asyncio_detailed(
     workspace: str,
     *,
-    client: Client,
+    client: Union[AuthenticatedClient, Client],
     only_member_of: Union[Unset, None, bool] = UNSET,
 ) -> Response[List[str]]:
     """list group names
@@ -114,26 +120,28 @@ async def asyncio_detailed(
         workspace (str):
         only_member_of (Union[Unset, None, bool]):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
         Response[List[str]]
     """
 
     kwargs = _get_kwargs(
         workspace=workspace,
-        client=client,
         only_member_of=only_member_of,
     )
 
-    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
-        response = await _client.request(**kwargs)
+    response = await client.get_async_httpx_client().request(**kwargs)
 
-    return _build_response(response=response)
+    return _build_response(client=client, response=response)
 
 
 async def asyncio(
     workspace: str,
     *,
-    client: Client,
+    client: Union[AuthenticatedClient, Client],
     only_member_of: Union[Unset, None, bool] = UNSET,
 ) -> Optional[List[str]]:
     """list group names
@@ -142,8 +150,12 @@ async def asyncio(
         workspace (str):
         only_member_of (Union[Unset, None, bool]):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
-        Response[List[str]]
+        List[str]
     """
 
     return (
