@@ -29,6 +29,7 @@ def _get_kwargs(
     tag: Union[Unset, None, str] = UNSET,
     is_skipped: Union[Unset, None, bool] = UNSET,
     is_flow_step: Union[Unset, None, bool] = UNSET,
+    has_null_parent: Union[Unset, None, bool] = UNSET,
 ) -> Dict[str, Any]:
     pass
 
@@ -73,6 +74,8 @@ def _get_kwargs(
 
     params["is_flow_step"] = is_flow_step
 
+    params["has_null_parent"] = has_null_parent
+
     params = {k: v for k, v in params.items() if v is not UNSET and v is not None}
 
     return {
@@ -133,6 +136,7 @@ def sync_detailed(
     tag: Union[Unset, None, str] = UNSET,
     is_skipped: Union[Unset, None, bool] = UNSET,
     is_flow_step: Union[Unset, None, bool] = UNSET,
+    has_null_parent: Union[Unset, None, bool] = UNSET,
 ) -> Response[List["ListCompletedJobsResponse200Item"]]:
     """list all completed jobs
 
@@ -154,6 +158,7 @@ def sync_detailed(
         tag (Union[Unset, None, str]):
         is_skipped (Union[Unset, None, bool]):
         is_flow_step (Union[Unset, None, bool]):
+        has_null_parent (Union[Unset, None, bool]):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -181,6 +186,7 @@ def sync_detailed(
         tag=tag,
         is_skipped=is_skipped,
         is_flow_step=is_flow_step,
+        has_null_parent=has_null_parent,
     )
 
     response = client.get_httpx_client().request(
@@ -210,6 +216,7 @@ def sync(
     tag: Union[Unset, None, str] = UNSET,
     is_skipped: Union[Unset, None, bool] = UNSET,
     is_flow_step: Union[Unset, None, bool] = UNSET,
+    has_null_parent: Union[Unset, None, bool] = UNSET,
 ) -> Optional[List["ListCompletedJobsResponse200Item"]]:
     """list all completed jobs
 
@@ -231,6 +238,7 @@ def sync(
         tag (Union[Unset, None, str]):
         is_skipped (Union[Unset, None, bool]):
         is_flow_step (Union[Unset, None, bool]):
+        has_null_parent (Union[Unset, None, bool]):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -259,6 +267,7 @@ def sync(
         tag=tag,
         is_skipped=is_skipped,
         is_flow_step=is_flow_step,
+        has_null_parent=has_null_parent,
     ).parsed
 
 
@@ -282,6 +291,7 @@ async def asyncio_detailed(
     tag: Union[Unset, None, str] = UNSET,
     is_skipped: Union[Unset, None, bool] = UNSET,
     is_flow_step: Union[Unset, None, bool] = UNSET,
+    has_null_parent: Union[Unset, None, bool] = UNSET,
 ) -> Response[List["ListCompletedJobsResponse200Item"]]:
     """list all completed jobs
 
@@ -303,6 +313,7 @@ async def asyncio_detailed(
         tag (Union[Unset, None, str]):
         is_skipped (Union[Unset, None, bool]):
         is_flow_step (Union[Unset, None, bool]):
+        has_null_parent (Union[Unset, None, bool]):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -330,6 +341,7 @@ async def asyncio_detailed(
         tag=tag,
         is_skipped=is_skipped,
         is_flow_step=is_flow_step,
+        has_null_parent=has_null_parent,
     )
 
     response = await client.get_async_httpx_client().request(**kwargs)
@@ -357,6 +369,7 @@ async def asyncio(
     tag: Union[Unset, None, str] = UNSET,
     is_skipped: Union[Unset, None, bool] = UNSET,
     is_flow_step: Union[Unset, None, bool] = UNSET,
+    has_null_parent: Union[Unset, None, bool] = UNSET,
 ) -> Optional[List["ListCompletedJobsResponse200Item"]]:
     """list all completed jobs
 
@@ -378,6 +391,7 @@ async def asyncio(
         tag (Union[Unset, None, str]):
         is_skipped (Union[Unset, None, bool]):
         is_flow_step (Union[Unset, None, bool]):
+        has_null_parent (Union[Unset, None, bool]):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -407,5 +421,6 @@ async def asyncio(
             tag=tag,
             is_skipped=is_skipped,
             is_flow_step=is_flow_step,
+            has_null_parent=has_null_parent,
         )
     ).parsed
