@@ -31,7 +31,9 @@ def _get_kwargs(
     result: Union[Unset, None, str] = UNSET,
     is_skipped: Union[Unset, None, bool] = UNSET,
     is_flow_step: Union[Unset, None, bool] = UNSET,
+    has_null_parent: Union[Unset, None, bool] = UNSET,
     success: Union[Unset, None, bool] = UNSET,
+    all_workspaces: Union[Unset, None, bool] = UNSET,
 ) -> Dict[str, Any]:
     pass
 
@@ -88,8 +90,12 @@ def _get_kwargs(
 
     params["is_flow_step"] = is_flow_step
 
+    params["has_null_parent"] = has_null_parent
+
     params["success"] = success
 
+    params["all_workspaces"] = all_workspaces
+
     params = {k: v for k, v in params.items() if v is not UNSET and v is not None}
 
     return {
@@ -152,7 +158,9 @@ def sync_detailed(
     result: Union[Unset, None, str] = UNSET,
     is_skipped: Union[Unset, None, bool] = UNSET,
     is_flow_step: Union[Unset, None, bool] = UNSET,
+    has_null_parent: Union[Unset, None, bool] = UNSET,
     success: Union[Unset, None, bool] = UNSET,
+    all_workspaces: Union[Unset, None, bool] = UNSET,
 ) -> Response[List["ListJobsResponse200Item"]]:
     """list all jobs
 
@@ -176,7 +184,9 @@ def sync_detailed(
         result (Union[Unset, None, str]):
         is_skipped (Union[Unset, None, bool]):
         is_flow_step (Union[Unset, None, bool]):
+        has_null_parent (Union[Unset, None, bool]):
         success (Union[Unset, None, bool]):
+        all_workspaces (Union[Unset, None, bool]):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -206,7 +216,9 @@ def sync_detailed(
         result=result,
         is_skipped=is_skipped,
         is_flow_step=is_flow_step,
+        has_null_parent=has_null_parent,
         success=success,
+        all_workspaces=all_workspaces,
     )
 
     response = client.get_httpx_client().request(
@@ -238,7 +250,9 @@ def sync(
     result: Union[Unset, None, str] = UNSET,
     is_skipped: Union[Unset, None, bool] = UNSET,
     is_flow_step: Union[Unset, None, bool] = UNSET,
+    has_null_parent: Union[Unset, None, bool] = UNSET,
     success: Union[Unset, None, bool] = UNSET,
+    all_workspaces: Union[Unset, None, bool] = UNSET,
 ) -> Optional[List["ListJobsResponse200Item"]]:
     """list all jobs
 
@@ -262,7 +276,9 @@ def sync(
         result (Union[Unset, None, str]):
         is_skipped (Union[Unset, None, bool]):
         is_flow_step (Union[Unset, None, bool]):
+        has_null_parent (Union[Unset, None, bool]):
         success (Union[Unset, None, bool]):
+        all_workspaces (Union[Unset, None, bool]):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -293,7 +309,9 @@ def sync(
         result=result,
         is_skipped=is_skipped,
         is_flow_step=is_flow_step,
+        has_null_parent=has_null_parent,
         success=success,
+        all_workspaces=all_workspaces,
     ).parsed
 
 
@@ -319,7 +337,9 @@ async def asyncio_detailed(
     result: Union[Unset, None, str] = UNSET,
     is_skipped: Union[Unset, None, bool] = UNSET,
     is_flow_step: Union[Unset, None, bool] = UNSET,
+    has_null_parent: Union[Unset, None, bool] = UNSET,
     success: Union[Unset, None, bool] = UNSET,
+    all_workspaces: Union[Unset, None, bool] = UNSET,
 ) -> Response[List["ListJobsResponse200Item"]]:
     """list all jobs
 
@@ -343,7 +363,9 @@ async def asyncio_detailed(
         result (Union[Unset, None, str]):
         is_skipped (Union[Unset, None, bool]):
         is_flow_step (Union[Unset, None, bool]):
+        has_null_parent (Union[Unset, None, bool]):
         success (Union[Unset, None, bool]):
+        all_workspaces (Union[Unset, None, bool]):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -373,7 +395,9 @@ async def asyncio_detailed(
         result=result,
         is_skipped=is_skipped,
         is_flow_step=is_flow_step,
+        has_null_parent=has_null_parent,
         success=success,
+        all_workspaces=all_workspaces,
     )
 
     response = await client.get_async_httpx_client().request(**kwargs)
@@ -403,7 +427,9 @@ async def asyncio(
     result: Union[Unset, None, str] = UNSET,
     is_skipped: Union[Unset, None, bool] = UNSET,
     is_flow_step: Union[Unset, None, bool] = UNSET,
+    has_null_parent: Union[Unset, None, bool] = UNSET,
     success: Union[Unset, None, bool] = UNSET,
+    all_workspaces: Union[Unset, None, bool] = UNSET,
 ) -> Optional[List["ListJobsResponse200Item"]]:
     """list all jobs
 
@@ -427,7 +453,9 @@ async def asyncio(
         result (Union[Unset, None, str]):
         is_skipped (Union[Unset, None, bool]):
         is_flow_step (Union[Unset, None, bool]):
+        has_null_parent (Union[Unset, None, bool]):
         success (Union[Unset, None, bool]):
+        all_workspaces (Union[Unset, None, bool]):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -459,6 +487,8 @@ async def asyncio(
             result=result,
             is_skipped=is_skipped,
             is_flow_step=is_flow_step,
+            has_null_parent=has_null_parent,
             success=success,
+            all_workspaces=all_workspaces,
         )
     ).parsed
