@@ -18,6 +18,7 @@ def _get_kwargs(
     scheduled_for: Union[Unset, None, datetime.datetime] = UNSET,
     scheduled_in_secs: Union[Unset, None, int] = UNSET,
     parent_job: Union[Unset, None, str] = UNSET,
+    tag: Union[Unset, None, str] = UNSET,
     job_id: Union[Unset, None, str] = UNSET,
     include_header: Union[Unset, None, str] = UNSET,
     invisible_to_owner: Union[Unset, None, bool] = UNSET,
@@ -35,6 +36,8 @@ def _get_kwargs(
 
     params["parent_job"] = parent_job
 
+    params["tag"] = tag
+
     params["job_id"] = job_id
 
     params["include_header"] = include_header
@@ -81,6 +84,7 @@ def sync_detailed(
     scheduled_for: Union[Unset, None, datetime.datetime] = UNSET,
     scheduled_in_secs: Union[Unset, None, int] = UNSET,
     parent_job: Union[Unset, None, str] = UNSET,
+    tag: Union[Unset, None, str] = UNSET,
     job_id: Union[Unset, None, str] = UNSET,
     include_header: Union[Unset, None, str] = UNSET,
     invisible_to_owner: Union[Unset, None, bool] = UNSET,
@@ -93,6 +97,7 @@ def sync_detailed(
         scheduled_for (Union[Unset, None, datetime.datetime]):
         scheduled_in_secs (Union[Unset, None, int]):
         parent_job (Union[Unset, None, str]):
+        tag (Union[Unset, None, str]):
         job_id (Union[Unset, None, str]):
         include_header (Union[Unset, None, str]):
         invisible_to_owner (Union[Unset, None, bool]):
@@ -113,6 +118,7 @@ def sync_detailed(
         scheduled_for=scheduled_for,
         scheduled_in_secs=scheduled_in_secs,
         parent_job=parent_job,
+        tag=tag,
         job_id=job_id,
         include_header=include_header,
         invisible_to_owner=invisible_to_owner,
@@ -134,6 +140,7 @@ async def asyncio_detailed(
     scheduled_for: Union[Unset, None, datetime.datetime] = UNSET,
     scheduled_in_secs: Union[Unset, None, int] = UNSET,
     parent_job: Union[Unset, None, str] = UNSET,
+    tag: Union[Unset, None, str] = UNSET,
     job_id: Union[Unset, None, str] = UNSET,
     include_header: Union[Unset, None, str] = UNSET,
     invisible_to_owner: Union[Unset, None, bool] = UNSET,
@@ -146,6 +153,7 @@ async def asyncio_detailed(
         scheduled_for (Union[Unset, None, datetime.datetime]):
         scheduled_in_secs (Union[Unset, None, int]):
         parent_job (Union[Unset, None, str]):
+        tag (Union[Unset, None, str]):
         job_id (Union[Unset, None, str]):
         include_header (Union[Unset, None, str]):
         invisible_to_owner (Union[Unset, None, bool]):
@@ -166,6 +174,7 @@ async def asyncio_detailed(
         scheduled_for=scheduled_for,
         scheduled_in_secs=scheduled_in_secs,
         parent_job=parent_job,
+        tag=tag,
         job_id=job_id,
         include_header=include_header,
         invisible_to_owner=invisible_to_owner,
