@@ -18,6 +18,7 @@ def _get_kwargs(
     scheduled_for: Union[Unset, None, datetime.datetime] = UNSET,
     scheduled_in_secs: Union[Unset, None, int] = UNSET,
     parent_job: Union[Unset, None, str] = UNSET,
+    tag: Union[Unset, None, str] = UNSET,
     job_id: Union[Unset, None, str] = UNSET,
     invisible_to_owner: Union[Unset, None, bool] = UNSET,
 ) -> Dict[str, Any]:
@@ -34,6 +35,8 @@ def _get_kwargs(
 
     params["parent_job"] = parent_job
 
+    params["tag"] = tag
+
     params["job_id"] = job_id
 
     params["invisible_to_owner"] = invisible_to_owner
@@ -78,6 +81,7 @@ def sync_detailed(
     scheduled_for: Union[Unset, None, datetime.datetime] = UNSET,
     scheduled_in_secs: Union[Unset, None, int] = UNSET,
     parent_job: Union[Unset, None, str] = UNSET,
+    tag: Union[Unset, None, str] = UNSET,
     job_id: Union[Unset, None, str] = UNSET,
     invisible_to_owner: Union[Unset, None, bool] = UNSET,
 ) -> Response[Any]:
@@ -89,6 +93,7 @@ def sync_detailed(
         scheduled_for (Union[Unset, None, datetime.datetime]):
         scheduled_in_secs (Union[Unset, None, int]):
         parent_job (Union[Unset, None, str]):
+        tag (Union[Unset, None, str]):
         job_id (Union[Unset, None, str]):
         invisible_to_owner (Union[Unset, None, bool]):
         json_body (RunScriptByPathJsonBody):
@@ -108,6 +113,7 @@ def sync_detailed(
         scheduled_for=scheduled_for,
         scheduled_in_secs=scheduled_in_secs,
         parent_job=parent_job,
+        tag=tag,
         job_id=job_id,
         invisible_to_owner=invisible_to_owner,
     )
@@ -128,6 +134,7 @@ async def asyncio_detailed(
     scheduled_for: Union[Unset, None, datetime.datetime] = UNSET,
     scheduled_in_secs: Union[Unset, None, int] = UNSET,
     parent_job: Union[Unset, None, str] = UNSET,
+    tag: Union[Unset, None, str] = UNSET,
     job_id: Union[Unset, None, str] = UNSET,
     invisible_to_owner: Union[Unset, None, bool] = UNSET,
 ) -> Response[Any]:
@@ -139,6 +146,7 @@ async def asyncio_detailed(
         scheduled_for (Union[Unset, None, datetime.datetime]):
         scheduled_in_secs (Union[Unset, None, int]):
         parent_job (Union[Unset, None, str]):
+        tag (Union[Unset, None, str]):
         job_id (Union[Unset, None, str]):
         invisible_to_owner (Union[Unset, None, bool]):
         json_body (RunScriptByPathJsonBody):
@@ -158,6 +166,7 @@ async def asyncio_detailed(
         scheduled_for=scheduled_for,
         scheduled_in_secs=scheduled_in_secs,
         parent_job=parent_job,
+        tag=tag,
         job_id=job_id,
         invisible_to_owner=invisible_to_owner,
     )
