@@ -13,6 +13,7 @@ def _get_kwargs(
     *,
     page: Union[Unset, None, int] = UNSET,
     per_page: Union[Unset, None, int] = UNSET,
+    ping_since: Union[Unset, None, int] = UNSET,
 ) -> Dict[str, Any]:
     pass
 
@@ -21,6 +22,8 @@ def _get_kwargs(
 
     params["per_page"] = per_page
 
+    params["ping_since"] = ping_since
+
     params = {k: v for k, v in params.items() if v is not UNSET and v is not None}
 
     return {
@@ -64,12 +67,14 @@ def sync_detailed(
     client: Union[AuthenticatedClient, Client],
     page: Union[Unset, None, int] = UNSET,
     per_page: Union[Unset, None, int] = UNSET,
+    ping_since: Union[Unset, None, int] = UNSET,
 ) -> Response[List["ListWorkersResponse200Item"]]:
     """list workers
 
     Args:
         page (Union[Unset, None, int]):
         per_page (Union[Unset, None, int]):
+        ping_since (Union[Unset, None, int]):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -82,6 +87,7 @@ def sync_detailed(
     kwargs = _get_kwargs(
         page=page,
         per_page=per_page,
+        ping_since=ping_since,
     )
 
     response = client.get_httpx_client().request(
@@ -96,12 +102,14 @@ def sync(
     client: Union[AuthenticatedClient, Client],
     page: Union[Unset, None, int] = UNSET,
     per_page: Union[Unset, None, int] = UNSET,
+    ping_since: Union[Unset, None, int] = UNSET,
 ) -> Optional[List["ListWorkersResponse200Item"]]:
     """list workers
 
     Args:
         page (Union[Unset, None, int]):
         per_page (Union[Unset, None, int]):
+        ping_since (Union[Unset, None, int]):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -115,6 +123,7 @@ def sync(
         client=client,
         page=page,
         per_page=per_page,
+        ping_since=ping_since,
     ).parsed
 
 
@@ -123,12 +132,14 @@ async def asyncio_detailed(
     client: Union[AuthenticatedClient, Client],
     page: Union[Unset, None, int] = UNSET,
     per_page: Union[Unset, None, int] = UNSET,
+    ping_since: Union[Unset, None, int] = UNSET,
 ) -> Response[List["ListWorkersResponse200Item"]]:
     """list workers
 
     Args:
         page (Union[Unset, None, int]):
         per_page (Union[Unset, None, int]):
+        ping_since (Union[Unset, None, int]):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -141,6 +152,7 @@ async def asyncio_detailed(
     kwargs = _get_kwargs(
         page=page,
         per_page=per_page,
+        ping_since=ping_since,
     )
 
     response = await client.get_async_httpx_client().request(**kwargs)
@@ -153,12 +165,14 @@ async def asyncio(
     client: Union[AuthenticatedClient, Client],
     page: Union[Unset, None, int] = UNSET,
     per_page: Union[Unset, None, int] = UNSET,
+    ping_since: Union[Unset, None, int] = UNSET,
 ) -> Optional[List["ListWorkersResponse200Item"]]:
     """list workers
 
     Args:
         page (Union[Unset, None, int]):
         per_page (Union[Unset, None, int]):
+        ping_since (Union[Unset, None, int]):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -173,5 +187,6 @@ async def asyncio(
             client=client,
             page=page,
             per_page=per_page,
+            ping_since=ping_since,
         )
     ).parsed
