@@ -1,22 +1,26 @@
-from typing import Any, Dict, List, Type, TypeVar, Union, cast
+from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union, cast
 
-import attr
+from attrs import define as _attrs_define
+from attrs import field as _attrs_field
 
-from ..models.completed_job_flow_status_failure_module_approvers_item import (
-    CompletedJobFlowStatusFailureModuleApproversItem,
-)
-from ..models.completed_job_flow_status_failure_module_branch_chosen import (
-    CompletedJobFlowStatusFailureModuleBranchChosen,
-)
-from ..models.completed_job_flow_status_failure_module_branchall import CompletedJobFlowStatusFailureModuleBranchall
-from ..models.completed_job_flow_status_failure_module_iterator import CompletedJobFlowStatusFailureModuleIterator
 from ..models.completed_job_flow_status_failure_module_type import CompletedJobFlowStatusFailureModuleType
 from ..types import UNSET, Unset
 
+if TYPE_CHECKING:
+    from ..models.completed_job_flow_status_failure_module_approvers_item import (
+        CompletedJobFlowStatusFailureModuleApproversItem,
+    )
+    from ..models.completed_job_flow_status_failure_module_branch_chosen import (
+        CompletedJobFlowStatusFailureModuleBranchChosen,
+    )
+    from ..models.completed_job_flow_status_failure_module_branchall import CompletedJobFlowStatusFailureModuleBranchall
+    from ..models.completed_job_flow_status_failure_module_iterator import CompletedJobFlowStatusFailureModuleIterator
+
+
 T = TypeVar("T", bound="CompletedJobFlowStatusFailureModule")
 
 
-@attr.s(auto_attribs=True)
+@_attrs_define
 class CompletedJobFlowStatusFailureModule:
     """
     Attributes:
@@ -28,7 +32,7 @@ class CompletedJobFlowStatusFailureModule:
         flow_jobs (Union[Unset, List[str]]):
         branch_chosen (Union[Unset, CompletedJobFlowStatusFailureModuleBranchChosen]):
         branchall (Union[Unset, CompletedJobFlowStatusFailureModuleBranchall]):
-        approvers (Union[Unset, List[CompletedJobFlowStatusFailureModuleApproversItem]]):
+        approvers (Union[Unset, List['CompletedJobFlowStatusFailureModuleApproversItem']]):
         parent_module (Union[Unset, str]):
     """
 
@@ -36,13 +40,13 @@ class CompletedJobFlowStatusFailureModule:
     id: Union[Unset, str] = UNSET
     job: Union[Unset, str] = UNSET
     count: Union[Unset, int] = UNSET
-    iterator: Union[Unset, CompletedJobFlowStatusFailureModuleIterator] = UNSET
+    iterator: Union[Unset, "CompletedJobFlowStatusFailureModuleIterator"] = UNSET
     flow_jobs: Union[Unset, List[str]] = UNSET
-    branch_chosen: Union[Unset, CompletedJobFlowStatusFailureModuleBranchChosen] = UNSET
-    branchall: Union[Unset, CompletedJobFlowStatusFailureModuleBranchall] = UNSET
-    approvers: Union[Unset, List[CompletedJobFlowStatusFailureModuleApproversItem]] = UNSET
+    branch_chosen: Union[Unset, "CompletedJobFlowStatusFailureModuleBranchChosen"] = UNSET
+    branchall: Union[Unset, "CompletedJobFlowStatusFailureModuleBranchall"] = UNSET
+    approvers: Union[Unset, List["CompletedJobFlowStatusFailureModuleApproversItem"]] = UNSET
     parent_module: Union[Unset, str] = UNSET
-    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
+    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
         type = self.type.value
@@ -106,6 +110,19 @@ class CompletedJobFlowStatusFailureModule:
 
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+        from ..models.completed_job_flow_status_failure_module_approvers_item import (
+            CompletedJobFlowStatusFailureModuleApproversItem,
+        )
+        from ..models.completed_job_flow_status_failure_module_branch_chosen import (
+            CompletedJobFlowStatusFailureModuleBranchChosen,
+        )
+        from ..models.completed_job_flow_status_failure_module_branchall import (
+            CompletedJobFlowStatusFailureModuleBranchall,
+        )
+        from ..models.completed_job_flow_status_failure_module_iterator import (
+            CompletedJobFlowStatusFailureModuleIterator,
+        )
+
         d = src_dict.copy()
         type = CompletedJobFlowStatusFailureModuleType(d.pop("type"))
 
