@@ -41,6 +41,7 @@ class CreateScriptJsonBody:
         timeout (Union[Unset, int]):
         delete_after_use (Union[Unset, bool]):
         deployment_message (Union[Unset, str]):
+        concurrency_key (Union[Unset, str]):
     """
 
     path: str
@@ -66,6 +67,7 @@ class CreateScriptJsonBody:
     timeout: Union[Unset, int] = UNSET
     delete_after_use: Union[Unset, bool] = UNSET
     deployment_message: Union[Unset, str] = UNSET
+    concurrency_key: Union[Unset, str] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -102,6 +104,7 @@ class CreateScriptJsonBody:
         timeout = self.timeout
         delete_after_use = self.delete_after_use
         deployment_message = self.deployment_message
+        concurrency_key = self.concurrency_key
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
@@ -150,6 +153,8 @@ class CreateScriptJsonBody:
             field_dict["delete_after_use"] = delete_after_use
         if deployment_message is not UNSET:
             field_dict["deployment_message"] = deployment_message
+        if concurrency_key is not UNSET:
+            field_dict["concurrency_key"] = concurrency_key
 
         return field_dict
 
@@ -214,6 +219,8 @@ class CreateScriptJsonBody:
 
         deployment_message = d.pop("deployment_message", UNSET)
 
+        concurrency_key = d.pop("concurrency_key", UNSET)
+
         create_script_json_body = cls(
             path=path,
             summary=summary,
@@ -238,6 +245,7 @@ class CreateScriptJsonBody:
             timeout=timeout,
             delete_after_use=delete_after_use,
             deployment_message=deployment_message,
+            concurrency_key=concurrency_key,
         )
 
         create_script_json_body.additional_properties = d
