@@ -1,8 +1,10 @@
-from typing import Any, Dict, List, Type, TypeVar
+from typing import Any, Dict, List, Type, TypeVar, Union
 
 from attrs import define as _attrs_define
 from attrs import field as _attrs_field
 
+from ..types import UNSET, Unset
+
 T = TypeVar("T", bound="CreateWorkspace")
 
 
@@ -12,12 +14,12 @@ class CreateWorkspace:
     Attributes:
         id (str):
         name (str):
-        username (str):
+        username (Union[Unset, str]):
     """
 
     id: str
     name: str
-    username: str
+    username: Union[Unset, str] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -31,9 +33,10 @@ class CreateWorkspace:
             {
                 "id": id,
                 "name": name,
-                "username": username,
             }
         )
+        if username is not UNSET:
+            field_dict["username"] = username
 
         return field_dict
 
@@ -44,7 +47,7 @@ class CreateWorkspace:
 
         name = d.pop("name")
 
-        username = d.pop("username")
+        username = d.pop("username", UNSET)
 
         create_workspace = cls(
             id=id,
