@@ -2,6 +2,9 @@ from enum import Enum
 
 
 class EditLargeFileStorageConfigJsonBodyLargeFileStorageType(str, Enum):
+    AZUREBLOBSTORAGE = "AzureBlobStorage"
+    AZUREWORKLOADIDENTITY = "AzureWorkloadIdentity"
+    S3AWSOIDC = "S3AwsOidc"
     S3STORAGE = "S3Storage"
 
     def __str__(self) -> str:
