@@ -24,6 +24,7 @@ class FlowModuleSuspend:
         user_auth_required (Union[Unset, bool]):
         user_groups_required (Union['FlowModuleSuspendUserGroupsRequiredType0',
             'FlowModuleSuspendUserGroupsRequiredType1', Unset]):
+        self_approval_disabled (Union[Unset, bool]):
     """
 
     required_events: Union[Unset, int] = UNSET
@@ -33,6 +34,7 @@ class FlowModuleSuspend:
     user_groups_required: Union[
         "FlowModuleSuspendUserGroupsRequiredType0", "FlowModuleSuspendUserGroupsRequiredType1", Unset
     ] = UNSET
+    self_approval_disabled: Union[Unset, bool] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -59,6 +61,8 @@ class FlowModuleSuspend:
             if not isinstance(self.user_groups_required, Unset):
                 user_groups_required = self.user_groups_required.to_dict()
 
+        self_approval_disabled = self.self_approval_disabled
+
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
         field_dict.update({})
@@ -72,6 +76,8 @@ class FlowModuleSuspend:
             field_dict["user_auth_required"] = user_auth_required
         if user_groups_required is not UNSET:
             field_dict["user_groups_required"] = user_groups_required
+        if self_approval_disabled is not UNSET:
+            field_dict["self_approval_disabled"] = self_approval_disabled
 
         return field_dict
 
@@ -130,12 +136,15 @@ class FlowModuleSuspend:
 
         user_groups_required = _parse_user_groups_required(d.pop("user_groups_required", UNSET))
 
+        self_approval_disabled = d.pop("self_approval_disabled", UNSET)
+
         flow_module_suspend = cls(
             required_events=required_events,
             timeout=timeout,
             resume_form=resume_form,
             user_auth_required=user_auth_required,
             user_groups_required=user_groups_required,
+            self_approval_disabled=self_approval_disabled,
         )
 
         flow_module_suspend.additional_properties = d
