@@ -1,18 +1,22 @@
-from typing import Any, Dict, List, Type, TypeVar, Union, cast
+from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union, cast
 
-import attr
+from attrs import define as _attrs_define
+from attrs import field as _attrs_field
 
-from ..models.flow_status_failure_module_approvers_item import FlowStatusFailureModuleApproversItem
-from ..models.flow_status_failure_module_branch_chosen import FlowStatusFailureModuleBranchChosen
-from ..models.flow_status_failure_module_branchall import FlowStatusFailureModuleBranchall
-from ..models.flow_status_failure_module_iterator import FlowStatusFailureModuleIterator
 from ..models.flow_status_failure_module_type import FlowStatusFailureModuleType
 from ..types import UNSET, Unset
 
+if TYPE_CHECKING:
+    from ..models.flow_status_failure_module_approvers_item import FlowStatusFailureModuleApproversItem
+    from ..models.flow_status_failure_module_branch_chosen import FlowStatusFailureModuleBranchChosen
+    from ..models.flow_status_failure_module_branchall import FlowStatusFailureModuleBranchall
+    from ..models.flow_status_failure_module_iterator import FlowStatusFailureModuleIterator
+
+
 T = TypeVar("T", bound="FlowStatusFailureModule")
 
 
-@attr.s(auto_attribs=True)
+@_attrs_define
 class FlowStatusFailureModule:
     """
     Attributes:
@@ -24,7 +28,7 @@ class FlowStatusFailureModule:
         flow_jobs (Union[Unset, List[str]]):
         branch_chosen (Union[Unset, FlowStatusFailureModuleBranchChosen]):
         branchall (Union[Unset, FlowStatusFailureModuleBranchall]):
-        approvers (Union[Unset, List[FlowStatusFailureModuleApproversItem]]):
+        approvers (Union[Unset, List['FlowStatusFailureModuleApproversItem']]):
         parent_module (Union[Unset, str]):
     """
 
@@ -32,13 +36,13 @@ class FlowStatusFailureModule:
     id: Union[Unset, str] = UNSET
     job: Union[Unset, str] = UNSET
     count: Union[Unset, int] = UNSET
-    iterator: Union[Unset, FlowStatusFailureModuleIterator] = UNSET
+    iterator: Union[Unset, "FlowStatusFailureModuleIterator"] = UNSET
     flow_jobs: Union[Unset, List[str]] = UNSET
-    branch_chosen: Union[Unset, FlowStatusFailureModuleBranchChosen] = UNSET
-    branchall: Union[Unset, FlowStatusFailureModuleBranchall] = UNSET
-    approvers: Union[Unset, List[FlowStatusFailureModuleApproversItem]] = UNSET
+    branch_chosen: Union[Unset, "FlowStatusFailureModuleBranchChosen"] = UNSET
+    branchall: Union[Unset, "FlowStatusFailureModuleBranchall"] = UNSET
+    approvers: Union[Unset, List["FlowStatusFailureModuleApproversItem"]] = UNSET
     parent_module: Union[Unset, str] = UNSET
-    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
+    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
         type = self.type.value
@@ -102,6 +106,11 @@ class FlowStatusFailureModule:
 
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+        from ..models.flow_status_failure_module_approvers_item import FlowStatusFailureModuleApproversItem
+        from ..models.flow_status_failure_module_branch_chosen import FlowStatusFailureModuleBranchChosen
+        from ..models.flow_status_failure_module_branchall import FlowStatusFailureModuleBranchall
+        from ..models.flow_status_failure_module_iterator import FlowStatusFailureModuleIterator
+
         d = src_dict.copy()
         type = FlowStatusFailureModuleType(d.pop("type"))
 
