@@ -28,6 +28,7 @@ class ForloopFlowModulesItemSuspend:
         user_auth_required (Union[Unset, bool]):
         user_groups_required (Union['ForloopFlowModulesItemSuspendUserGroupsRequiredType0',
             'ForloopFlowModulesItemSuspendUserGroupsRequiredType1', Unset]):
+        self_approval_disabled (Union[Unset, bool]):
     """
 
     required_events: Union[Unset, int] = UNSET
@@ -39,6 +40,7 @@ class ForloopFlowModulesItemSuspend:
         "ForloopFlowModulesItemSuspendUserGroupsRequiredType1",
         Unset,
     ] = UNSET
+    self_approval_disabled: Union[Unset, bool] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -67,6 +69,8 @@ class ForloopFlowModulesItemSuspend:
             if not isinstance(self.user_groups_required, Unset):
                 user_groups_required = self.user_groups_required.to_dict()
 
+        self_approval_disabled = self.self_approval_disabled
+
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
         field_dict.update({})
@@ -80,6 +84,8 @@ class ForloopFlowModulesItemSuspend:
             field_dict["user_auth_required"] = user_auth_required
         if user_groups_required is not UNSET:
             field_dict["user_groups_required"] = user_groups_required
+        if self_approval_disabled is not UNSET:
+            field_dict["self_approval_disabled"] = self_approval_disabled
 
         return field_dict
 
@@ -146,12 +152,15 @@ class ForloopFlowModulesItemSuspend:
 
         user_groups_required = _parse_user_groups_required(d.pop("user_groups_required", UNSET))
 
+        self_approval_disabled = d.pop("self_approval_disabled", UNSET)
+
         forloop_flow_modules_item_suspend = cls(
             required_events=required_events,
             timeout=timeout,
             resume_form=resume_form,
             user_auth_required=user_auth_required,
             user_groups_required=user_groups_required,
+            self_approval_disabled=self_approval_disabled,
         )
 
         forloop_flow_modules_item_suspend.additional_properties = d
