@@ -1,15 +1,21 @@
-from typing import Any, Dict, List, Type, TypeVar, Union
+from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union
 
-import attr
+from attrs import define as _attrs_define
+from attrs import field as _attrs_field
 
 from ..models.get_app_by_version_response_200_policy_execution_mode import GetAppByVersionResponse200PolicyExecutionMode
-from ..models.get_app_by_version_response_200_policy_triggerables import GetAppByVersionResponse200PolicyTriggerables
 from ..types import UNSET, Unset
 
+if TYPE_CHECKING:
+    from ..models.get_app_by_version_response_200_policy_triggerables import (
+        GetAppByVersionResponse200PolicyTriggerables,
+    )
+
+
 T = TypeVar("T", bound="GetAppByVersionResponse200Policy")
 
 
-@attr.s(auto_attribs=True)
+@_attrs_define
 class GetAppByVersionResponse200Policy:
     """
     Attributes:
@@ -19,11 +25,11 @@ class GetAppByVersionResponse200Policy:
         on_behalf_of_email (Union[Unset, str]):
     """
 
-    triggerables: Union[Unset, GetAppByVersionResponse200PolicyTriggerables] = UNSET
+    triggerables: Union[Unset, "GetAppByVersionResponse200PolicyTriggerables"] = UNSET
     execution_mode: Union[Unset, GetAppByVersionResponse200PolicyExecutionMode] = UNSET
     on_behalf_of: Union[Unset, str] = UNSET
     on_behalf_of_email: Union[Unset, str] = UNSET
-    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
+    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
         triggerables: Union[Unset, Dict[str, Any]] = UNSET
@@ -53,6 +59,10 @@ class GetAppByVersionResponse200Policy:
 
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+        from ..models.get_app_by_version_response_200_policy_triggerables import (
+            GetAppByVersionResponse200PolicyTriggerables,
+        )
+
         d = src_dict.copy()
         _triggerables = d.pop("triggerables", UNSET)
         triggerables: Union[Unset, GetAppByVersionResponse200PolicyTriggerables]
