@@ -30,6 +30,7 @@ class GetFlowByPathResponse200ValueFailureModuleSuspend:
         user_auth_required (Union[Unset, bool]):
         user_groups_required (Union['GetFlowByPathResponse200ValueFailureModuleSuspendUserGroupsRequiredType0',
             'GetFlowByPathResponse200ValueFailureModuleSuspendUserGroupsRequiredType1', Unset]):
+        self_approval_disabled (Union[Unset, bool]):
     """
 
     required_events: Union[Unset, int] = UNSET
@@ -41,6 +42,7 @@ class GetFlowByPathResponse200ValueFailureModuleSuspend:
         "GetFlowByPathResponse200ValueFailureModuleSuspendUserGroupsRequiredType1",
         Unset,
     ] = UNSET
+    self_approval_disabled: Union[Unset, bool] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -71,6 +73,8 @@ class GetFlowByPathResponse200ValueFailureModuleSuspend:
             if not isinstance(self.user_groups_required, Unset):
                 user_groups_required = self.user_groups_required.to_dict()
 
+        self_approval_disabled = self.self_approval_disabled
+
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
         field_dict.update({})
@@ -84,6 +88,8 @@ class GetFlowByPathResponse200ValueFailureModuleSuspend:
             field_dict["user_auth_required"] = user_auth_required
         if user_groups_required is not UNSET:
             field_dict["user_groups_required"] = user_groups_required
+        if self_approval_disabled is not UNSET:
+            field_dict["self_approval_disabled"] = self_approval_disabled
 
         return field_dict
 
@@ -160,12 +166,15 @@ class GetFlowByPathResponse200ValueFailureModuleSuspend:
 
         user_groups_required = _parse_user_groups_required(d.pop("user_groups_required", UNSET))
 
+        self_approval_disabled = d.pop("self_approval_disabled", UNSET)
+
         get_flow_by_path_response_200_value_failure_module_suspend = cls(
             required_events=required_events,
             timeout=timeout,
             resume_form=resume_form,
             user_auth_required=user_auth_required,
             user_groups_required=user_groups_required,
+            self_approval_disabled=self_approval_disabled,
         )
 
         get_flow_by_path_response_200_value_failure_module_suspend.additional_properties = d
