@@ -31,6 +31,7 @@ class GetFlowByPathWithDraftResponse200DraftValueFailureModuleSuspend:
         user_groups_required
             (Union['GetFlowByPathWithDraftResponse200DraftValueFailureModuleSuspendUserGroupsRequiredType0',
             'GetFlowByPathWithDraftResponse200DraftValueFailureModuleSuspendUserGroupsRequiredType1', Unset]):
+        self_approval_disabled (Union[Unset, bool]):
     """
 
     required_events: Union[Unset, int] = UNSET
@@ -42,6 +43,7 @@ class GetFlowByPathWithDraftResponse200DraftValueFailureModuleSuspend:
         "GetFlowByPathWithDraftResponse200DraftValueFailureModuleSuspendUserGroupsRequiredType1",
         Unset,
     ] = UNSET
+    self_approval_disabled: Union[Unset, bool] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -73,6 +75,8 @@ class GetFlowByPathWithDraftResponse200DraftValueFailureModuleSuspend:
             if not isinstance(self.user_groups_required, Unset):
                 user_groups_required = self.user_groups_required.to_dict()
 
+        self_approval_disabled = self.self_approval_disabled
+
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
         field_dict.update({})
@@ -86,6 +90,8 @@ class GetFlowByPathWithDraftResponse200DraftValueFailureModuleSuspend:
             field_dict["user_auth_required"] = user_auth_required
         if user_groups_required is not UNSET:
             field_dict["user_groups_required"] = user_groups_required
+        if self_approval_disabled is not UNSET:
+            field_dict["self_approval_disabled"] = self_approval_disabled
 
         return field_dict
 
@@ -162,12 +168,15 @@ class GetFlowByPathWithDraftResponse200DraftValueFailureModuleSuspend:
 
         user_groups_required = _parse_user_groups_required(d.pop("user_groups_required", UNSET))
 
+        self_approval_disabled = d.pop("self_approval_disabled", UNSET)
+
         get_flow_by_path_with_draft_response_200_draft_value_failure_module_suspend = cls(
             required_events=required_events,
             timeout=timeout,
             resume_form=resume_form,
             user_auth_required=user_auth_required,
             user_groups_required=user_groups_required,
+            self_approval_disabled=self_approval_disabled,
         )
 
         get_flow_by_path_with_draft_response_200_draft_value_failure_module_suspend.additional_properties = d
