@@ -1,10 +1,14 @@
-from typing import Any, Dict, List, Type, TypeVar, Union
+from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union
 
 from attrs import define as _attrs_define
 from attrs import field as _attrs_field
 
 from ..types import UNSET, Unset
 
+if TYPE_CHECKING:
+    from ..models.get_job_updates_response_200_flow_status import GetJobUpdatesResponse200FlowStatus
+
+
 T = TypeVar("T", bound="GetJobUpdatesResponse200")
 
 
@@ -16,12 +20,14 @@ class GetJobUpdatesResponse200:
         completed (Union[Unset, bool]):
         new_logs (Union[Unset, str]):
         mem_peak (Union[Unset, int]):
+        flow_status (Union[Unset, GetJobUpdatesResponse200FlowStatus]):
     """
 
     running: Union[Unset, bool] = UNSET
     completed: Union[Unset, bool] = UNSET
     new_logs: Union[Unset, str] = UNSET
     mem_peak: Union[Unset, int] = UNSET
+    flow_status: Union[Unset, "GetJobUpdatesResponse200FlowStatus"] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -29,6 +35,9 @@ class GetJobUpdatesResponse200:
         completed = self.completed
         new_logs = self.new_logs
         mem_peak = self.mem_peak
+        flow_status: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.flow_status, Unset):
+            flow_status = self.flow_status.to_dict()
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
@@ -41,11 +50,15 @@ class GetJobUpdatesResponse200:
             field_dict["new_logs"] = new_logs
         if mem_peak is not UNSET:
             field_dict["mem_peak"] = mem_peak
+        if flow_status is not UNSET:
+            field_dict["flow_status"] = flow_status
 
         return field_dict
 
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+        from ..models.get_job_updates_response_200_flow_status import GetJobUpdatesResponse200FlowStatus
+
         d = src_dict.copy()
         running = d.pop("running", UNSET)
 
@@ -55,11 +68,19 @@ class GetJobUpdatesResponse200:
 
         mem_peak = d.pop("mem_peak", UNSET)
 
+        _flow_status = d.pop("flow_status", UNSET)
+        flow_status: Union[Unset, GetJobUpdatesResponse200FlowStatus]
+        if isinstance(_flow_status, Unset):
+            flow_status = UNSET
+        else:
+            flow_status = GetJobUpdatesResponse200FlowStatus.from_dict(_flow_status)
+
         get_job_updates_response_200 = cls(
             running=running,
             completed=completed,
             new_logs=new_logs,
             mem_peak=mem_peak,
+            flow_status=flow_status,
         )
 
         get_job_updates_response_200.additional_properties = d
