@@ -45,6 +45,7 @@ class GetScriptByPathWithDraftResponse200Draft:
         timeout (Union[Unset, int]):
         delete_after_use (Union[Unset, bool]):
         deployment_message (Union[Unset, str]):
+        concurrency_key (Union[Unset, str]):
     """
 
     path: str
@@ -70,6 +71,7 @@ class GetScriptByPathWithDraftResponse200Draft:
     timeout: Union[Unset, int] = UNSET
     delete_after_use: Union[Unset, bool] = UNSET
     deployment_message: Union[Unset, str] = UNSET
+    concurrency_key: Union[Unset, str] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -106,6 +108,7 @@ class GetScriptByPathWithDraftResponse200Draft:
         timeout = self.timeout
         delete_after_use = self.delete_after_use
         deployment_message = self.deployment_message
+        concurrency_key = self.concurrency_key
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
@@ -154,6 +157,8 @@ class GetScriptByPathWithDraftResponse200Draft:
             field_dict["delete_after_use"] = delete_after_use
         if deployment_message is not UNSET:
             field_dict["deployment_message"] = deployment_message
+        if concurrency_key is not UNSET:
+            field_dict["concurrency_key"] = concurrency_key
 
         return field_dict
 
@@ -220,6 +225,8 @@ class GetScriptByPathWithDraftResponse200Draft:
 
         deployment_message = d.pop("deployment_message", UNSET)
 
+        concurrency_key = d.pop("concurrency_key", UNSET)
+
         get_script_by_path_with_draft_response_200_draft = cls(
             path=path,
             summary=summary,
@@ -244,6 +251,7 @@ class GetScriptByPathWithDraftResponse200Draft:
             timeout=timeout,
             delete_after_use=delete_after_use,
             deployment_message=deployment_message,
+            concurrency_key=concurrency_key,
         )
 
         get_script_by_path_with_draft_response_200_draft.additional_properties = d
