@@ -1,17 +1,21 @@
 import datetime
-from typing import Any, Dict, List, Type, TypeVar, Union
+from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union
 
-import attr
+from attrs import define as _attrs_define
+from attrs import field as _attrs_field
 from dateutil.parser import isoparse
 
 from ..models.list_apps_response_200_item_execution_mode import ListAppsResponse200ItemExecutionMode
-from ..models.list_apps_response_200_item_extra_perms import ListAppsResponse200ItemExtraPerms
 from ..types import UNSET, Unset
 
+if TYPE_CHECKING:
+    from ..models.list_apps_response_200_item_extra_perms import ListAppsResponse200ItemExtraPerms
+
+
 T = TypeVar("T", bound="ListAppsResponse200Item")
 
 
-@attr.s(auto_attribs=True)
+@_attrs_define
 class ListAppsResponse200Item:
     """
     Attributes:
@@ -31,11 +35,11 @@ class ListAppsResponse200Item:
     path: str
     summary: str
     version: int
-    extra_perms: ListAppsResponse200ItemExtraPerms
+    extra_perms: "ListAppsResponse200ItemExtraPerms"
     edited_at: datetime.datetime
     execution_mode: ListAppsResponse200ItemExecutionMode
     starred: Union[Unset, bool] = UNSET
-    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
+    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
         id = self.id
@@ -72,6 +76,8 @@ class ListAppsResponse200Item:
 
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+        from ..models.list_apps_response_200_item_extra_perms import ListAppsResponse200ItemExtraPerms
+
         d = src_dict.copy()
         id = d.pop("id")
 
