@@ -1,28 +1,32 @@
-from typing import Any, Dict, List, Type, TypeVar, Union, cast
+from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union, cast
 
-import attr
+from attrs import define as _attrs_define
+from attrs import field as _attrs_field
 
-from ..models.list_queue_response_200_item_flow_status_failure_module_approvers_item import (
-    ListQueueResponse200ItemFlowStatusFailureModuleApproversItem,
-)
-from ..models.list_queue_response_200_item_flow_status_failure_module_branch_chosen import (
-    ListQueueResponse200ItemFlowStatusFailureModuleBranchChosen,
-)
-from ..models.list_queue_response_200_item_flow_status_failure_module_branchall import (
-    ListQueueResponse200ItemFlowStatusFailureModuleBranchall,
-)
-from ..models.list_queue_response_200_item_flow_status_failure_module_iterator import (
-    ListQueueResponse200ItemFlowStatusFailureModuleIterator,
-)
 from ..models.list_queue_response_200_item_flow_status_failure_module_type import (
     ListQueueResponse200ItemFlowStatusFailureModuleType,
 )
 from ..types import UNSET, Unset
 
+if TYPE_CHECKING:
+    from ..models.list_queue_response_200_item_flow_status_failure_module_approvers_item import (
+        ListQueueResponse200ItemFlowStatusFailureModuleApproversItem,
+    )
+    from ..models.list_queue_response_200_item_flow_status_failure_module_branch_chosen import (
+        ListQueueResponse200ItemFlowStatusFailureModuleBranchChosen,
+    )
+    from ..models.list_queue_response_200_item_flow_status_failure_module_branchall import (
+        ListQueueResponse200ItemFlowStatusFailureModuleBranchall,
+    )
+    from ..models.list_queue_response_200_item_flow_status_failure_module_iterator import (
+        ListQueueResponse200ItemFlowStatusFailureModuleIterator,
+    )
+
+
 T = TypeVar("T", bound="ListQueueResponse200ItemFlowStatusFailureModule")
 
 
-@attr.s(auto_attribs=True)
+@_attrs_define
 class ListQueueResponse200ItemFlowStatusFailureModule:
     """
     Attributes:
@@ -34,7 +38,7 @@ class ListQueueResponse200ItemFlowStatusFailureModule:
         flow_jobs (Union[Unset, List[str]]):
         branch_chosen (Union[Unset, ListQueueResponse200ItemFlowStatusFailureModuleBranchChosen]):
         branchall (Union[Unset, ListQueueResponse200ItemFlowStatusFailureModuleBranchall]):
-        approvers (Union[Unset, List[ListQueueResponse200ItemFlowStatusFailureModuleApproversItem]]):
+        approvers (Union[Unset, List['ListQueueResponse200ItemFlowStatusFailureModuleApproversItem']]):
         parent_module (Union[Unset, str]):
     """
 
@@ -42,13 +46,13 @@ class ListQueueResponse200ItemFlowStatusFailureModule:
     id: Union[Unset, str] = UNSET
     job: Union[Unset, str] = UNSET
     count: Union[Unset, int] = UNSET
-    iterator: Union[Unset, ListQueueResponse200ItemFlowStatusFailureModuleIterator] = UNSET
+    iterator: Union[Unset, "ListQueueResponse200ItemFlowStatusFailureModuleIterator"] = UNSET
     flow_jobs: Union[Unset, List[str]] = UNSET
-    branch_chosen: Union[Unset, ListQueueResponse200ItemFlowStatusFailureModuleBranchChosen] = UNSET
-    branchall: Union[Unset, ListQueueResponse200ItemFlowStatusFailureModuleBranchall] = UNSET
-    approvers: Union[Unset, List[ListQueueResponse200ItemFlowStatusFailureModuleApproversItem]] = UNSET
+    branch_chosen: Union[Unset, "ListQueueResponse200ItemFlowStatusFailureModuleBranchChosen"] = UNSET
+    branchall: Union[Unset, "ListQueueResponse200ItemFlowStatusFailureModuleBranchall"] = UNSET
+    approvers: Union[Unset, List["ListQueueResponse200ItemFlowStatusFailureModuleApproversItem"]] = UNSET
     parent_module: Union[Unset, str] = UNSET
-    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
+    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
         type = self.type.value
@@ -112,6 +116,19 @@ class ListQueueResponse200ItemFlowStatusFailureModule:
 
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+        from ..models.list_queue_response_200_item_flow_status_failure_module_approvers_item import (
+            ListQueueResponse200ItemFlowStatusFailureModuleApproversItem,
+        )
+        from ..models.list_queue_response_200_item_flow_status_failure_module_branch_chosen import (
+            ListQueueResponse200ItemFlowStatusFailureModuleBranchChosen,
+        )
+        from ..models.list_queue_response_200_item_flow_status_failure_module_branchall import (
+            ListQueueResponse200ItemFlowStatusFailureModuleBranchall,
+        )
+        from ..models.list_queue_response_200_item_flow_status_failure_module_iterator import (
+            ListQueueResponse200ItemFlowStatusFailureModuleIterator,
+        )
+
         d = src_dict.copy()
         type = ListQueueResponse200ItemFlowStatusFailureModuleType(d.pop("type"))
 
