@@ -1,62 +1,76 @@
-from typing import Any, Dict, List, Type, TypeVar, Union
+from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union
 
-import attr
+from attrs import define as _attrs_define
+from attrs import field as _attrs_field
 
-from ..models.list_queue_response_200_item_raw_flow_modules_item_mock import (
-    ListQueueResponse200ItemRawFlowModulesItemMock,
-)
-from ..models.list_queue_response_200_item_raw_flow_modules_item_retry import (
-    ListQueueResponse200ItemRawFlowModulesItemRetry,
-)
-from ..models.list_queue_response_200_item_raw_flow_modules_item_sleep_type_0 import (
-    ListQueueResponse200ItemRawFlowModulesItemSleepType0,
-)
-from ..models.list_queue_response_200_item_raw_flow_modules_item_sleep_type_1 import (
-    ListQueueResponse200ItemRawFlowModulesItemSleepType1,
-)
-from ..models.list_queue_response_200_item_raw_flow_modules_item_stop_after_if import (
-    ListQueueResponse200ItemRawFlowModulesItemStopAfterIf,
-)
-from ..models.list_queue_response_200_item_raw_flow_modules_item_suspend import (
-    ListQueueResponse200ItemRawFlowModulesItemSuspend,
-)
 from ..types import UNSET, Unset
 
+if TYPE_CHECKING:
+    from ..models.list_queue_response_200_item_raw_flow_modules_item_mock import (
+        ListQueueResponse200ItemRawFlowModulesItemMock,
+    )
+    from ..models.list_queue_response_200_item_raw_flow_modules_item_retry import (
+        ListQueueResponse200ItemRawFlowModulesItemRetry,
+    )
+    from ..models.list_queue_response_200_item_raw_flow_modules_item_sleep_type_0 import (
+        ListQueueResponse200ItemRawFlowModulesItemSleepType0,
+    )
+    from ..models.list_queue_response_200_item_raw_flow_modules_item_sleep_type_1 import (
+        ListQueueResponse200ItemRawFlowModulesItemSleepType1,
+    )
+    from ..models.list_queue_response_200_item_raw_flow_modules_item_stop_after_if import (
+        ListQueueResponse200ItemRawFlowModulesItemStopAfterIf,
+    )
+    from ..models.list_queue_response_200_item_raw_flow_modules_item_suspend import (
+        ListQueueResponse200ItemRawFlowModulesItemSuspend,
+    )
+
+
 T = TypeVar("T", bound="ListQueueResponse200ItemRawFlowModulesItem")
 
 
-@attr.s(auto_attribs=True)
+@_attrs_define
 class ListQueueResponse200ItemRawFlowModulesItem:
     """
     Attributes:
         id (str):
         value (Any):
         stop_after_if (Union[Unset, ListQueueResponse200ItemRawFlowModulesItemStopAfterIf]):
-        sleep (Union[ListQueueResponse200ItemRawFlowModulesItemSleepType0,
-            ListQueueResponse200ItemRawFlowModulesItemSleepType1, Unset]):
+        sleep (Union['ListQueueResponse200ItemRawFlowModulesItemSleepType0',
+            'ListQueueResponse200ItemRawFlowModulesItemSleepType1', Unset]):
         cache_ttl (Union[Unset, float]):
+        timeout (Union[Unset, float]):
+        delete_after_use (Union[Unset, bool]):
         summary (Union[Unset, str]):
         mock (Union[Unset, ListQueueResponse200ItemRawFlowModulesItemMock]):
         suspend (Union[Unset, ListQueueResponse200ItemRawFlowModulesItemSuspend]):
+        priority (Union[Unset, float]):
         retry (Union[Unset, ListQueueResponse200ItemRawFlowModulesItemRetry]):
     """
 
     id: str
     value: Any
-    stop_after_if: Union[Unset, ListQueueResponse200ItemRawFlowModulesItemStopAfterIf] = UNSET
+    stop_after_if: Union[Unset, "ListQueueResponse200ItemRawFlowModulesItemStopAfterIf"] = UNSET
     sleep: Union[
-        ListQueueResponse200ItemRawFlowModulesItemSleepType0,
-        ListQueueResponse200ItemRawFlowModulesItemSleepType1,
+        "ListQueueResponse200ItemRawFlowModulesItemSleepType0",
+        "ListQueueResponse200ItemRawFlowModulesItemSleepType1",
         Unset,
     ] = UNSET
     cache_ttl: Union[Unset, float] = UNSET
+    timeout: Union[Unset, float] = UNSET
+    delete_after_use: Union[Unset, bool] = UNSET
     summary: Union[Unset, str] = UNSET
-    mock: Union[Unset, ListQueueResponse200ItemRawFlowModulesItemMock] = UNSET
-    suspend: Union[Unset, ListQueueResponse200ItemRawFlowModulesItemSuspend] = UNSET
-    retry: Union[Unset, ListQueueResponse200ItemRawFlowModulesItemRetry] = UNSET
-    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
+    mock: Union[Unset, "ListQueueResponse200ItemRawFlowModulesItemMock"] = UNSET
+    suspend: Union[Unset, "ListQueueResponse200ItemRawFlowModulesItemSuspend"] = UNSET
+    priority: Union[Unset, float] = UNSET
+    retry: Union[Unset, "ListQueueResponse200ItemRawFlowModulesItemRetry"] = UNSET
+    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
+        from ..models.list_queue_response_200_item_raw_flow_modules_item_sleep_type_0 import (
+            ListQueueResponse200ItemRawFlowModulesItemSleepType0,
+        )
+
         id = self.id
         value = self.value
         stop_after_if: Union[Unset, Dict[str, Any]] = UNSET
@@ -78,6 +92,8 @@ class ListQueueResponse200ItemRawFlowModulesItem:
                 sleep = self.sleep.to_dict()
 
         cache_ttl = self.cache_ttl
+        timeout = self.timeout
+        delete_after_use = self.delete_after_use
         summary = self.summary
         mock: Union[Unset, Dict[str, Any]] = UNSET
         if not isinstance(self.mock, Unset):
@@ -87,6 +103,7 @@ class ListQueueResponse200ItemRawFlowModulesItem:
         if not isinstance(self.suspend, Unset):
             suspend = self.suspend.to_dict()
 
+        priority = self.priority
         retry: Union[Unset, Dict[str, Any]] = UNSET
         if not isinstance(self.retry, Unset):
             retry = self.retry.to_dict()
@@ -105,12 +122,18 @@ class ListQueueResponse200ItemRawFlowModulesItem:
             field_dict["sleep"] = sleep
         if cache_ttl is not UNSET:
             field_dict["cache_ttl"] = cache_ttl
+        if timeout is not UNSET:
+            field_dict["timeout"] = timeout
+        if delete_after_use is not UNSET:
+            field_dict["delete_after_use"] = delete_after_use
         if summary is not UNSET:
             field_dict["summary"] = summary
         if mock is not UNSET:
             field_dict["mock"] = mock
         if suspend is not UNSET:
             field_dict["suspend"] = suspend
+        if priority is not UNSET:
+            field_dict["priority"] = priority
         if retry is not UNSET:
             field_dict["retry"] = retry
 
@@ -118,6 +141,25 @@ class ListQueueResponse200ItemRawFlowModulesItem:
 
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+        from ..models.list_queue_response_200_item_raw_flow_modules_item_mock import (
+            ListQueueResponse200ItemRawFlowModulesItemMock,
+        )
+        from ..models.list_queue_response_200_item_raw_flow_modules_item_retry import (
+            ListQueueResponse200ItemRawFlowModulesItemRetry,
+        )
+        from ..models.list_queue_response_200_item_raw_flow_modules_item_sleep_type_0 import (
+            ListQueueResponse200ItemRawFlowModulesItemSleepType0,
+        )
+        from ..models.list_queue_response_200_item_raw_flow_modules_item_sleep_type_1 import (
+            ListQueueResponse200ItemRawFlowModulesItemSleepType1,
+        )
+        from ..models.list_queue_response_200_item_raw_flow_modules_item_stop_after_if import (
+            ListQueueResponse200ItemRawFlowModulesItemStopAfterIf,
+        )
+        from ..models.list_queue_response_200_item_raw_flow_modules_item_suspend import (
+            ListQueueResponse200ItemRawFlowModulesItemSuspend,
+        )
+
         d = src_dict.copy()
         id = d.pop("id")
 
@@ -133,8 +175,8 @@ class ListQueueResponse200ItemRawFlowModulesItem:
         def _parse_sleep(
             data: object,
         ) -> Union[
-            ListQueueResponse200ItemRawFlowModulesItemSleepType0,
-            ListQueueResponse200ItemRawFlowModulesItemSleepType1,
+            "ListQueueResponse200ItemRawFlowModulesItemSleepType0",
+            "ListQueueResponse200ItemRawFlowModulesItemSleepType1",
             Unset,
         ]:
             if isinstance(data, Unset):
@@ -167,6 +209,10 @@ class ListQueueResponse200ItemRawFlowModulesItem:
 
         cache_ttl = d.pop("cache_ttl", UNSET)
 
+        timeout = d.pop("timeout", UNSET)
+
+        delete_after_use = d.pop("delete_after_use", UNSET)
+
         summary = d.pop("summary", UNSET)
 
         _mock = d.pop("mock", UNSET)
@@ -183,6 +229,8 @@ class ListQueueResponse200ItemRawFlowModulesItem:
         else:
             suspend = ListQueueResponse200ItemRawFlowModulesItemSuspend.from_dict(_suspend)
 
+        priority = d.pop("priority", UNSET)
+
         _retry = d.pop("retry", UNSET)
         retry: Union[Unset, ListQueueResponse200ItemRawFlowModulesItemRetry]
         if isinstance(_retry, Unset):
@@ -196,9 +244,12 @@ class ListQueueResponse200ItemRawFlowModulesItem:
             stop_after_if=stop_after_if,
             sleep=sleep,
             cache_ttl=cache_ttl,
+            timeout=timeout,
+            delete_after_use=delete_after_use,
             summary=summary,
             mock=mock,
             suspend=suspend,
+            priority=priority,
             retry=retry,
         )
 
