@@ -16,6 +16,7 @@ if TYPE_CHECKING:
     from ..models.list_schedules_response_200_item_on_recovery_extra_args import (
         ListSchedulesResponse200ItemOnRecoveryExtraArgs,
     )
+    from ..models.list_schedules_response_200_item_retry import ListSchedulesResponse200ItemRetry
 
 
 T = TypeVar("T", bound="ListSchedulesResponse200Item")
@@ -45,6 +46,10 @@ class ListSchedulesResponse200Item:
         on_recovery_times (Union[Unset, float]):
         on_recovery_extra_args (Union[Unset, ListSchedulesResponse200ItemOnRecoveryExtraArgs]):
         ws_error_handler_muted (Union[Unset, bool]):
+        retry (Union[Unset, ListSchedulesResponse200ItemRetry]):
+        summary (Union[Unset, str]):
+        no_flow_overlap (Union[Unset, bool]):
+        tag (Union[Unset, str]):
     """
 
     path: str
@@ -67,6 +72,10 @@ class ListSchedulesResponse200Item:
     on_recovery_times: Union[Unset, float] = UNSET
     on_recovery_extra_args: Union[Unset, "ListSchedulesResponse200ItemOnRecoveryExtraArgs"] = UNSET
     ws_error_handler_muted: Union[Unset, bool] = UNSET
+    retry: Union[Unset, "ListSchedulesResponse200ItemRetry"] = UNSET
+    summary: Union[Unset, str] = UNSET
+    no_flow_overlap: Union[Unset, bool] = UNSET
+    tag: Union[Unset, str] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -101,6 +110,13 @@ class ListSchedulesResponse200Item:
             on_recovery_extra_args = self.on_recovery_extra_args.to_dict()
 
         ws_error_handler_muted = self.ws_error_handler_muted
+        retry: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.retry, Unset):
+            retry = self.retry.to_dict()
+
+        summary = self.summary
+        no_flow_overlap = self.no_flow_overlap
+        tag = self.tag
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
@@ -138,6 +154,14 @@ class ListSchedulesResponse200Item:
             field_dict["on_recovery_extra_args"] = on_recovery_extra_args
         if ws_error_handler_muted is not UNSET:
             field_dict["ws_error_handler_muted"] = ws_error_handler_muted
+        if retry is not UNSET:
+            field_dict["retry"] = retry
+        if summary is not UNSET:
+            field_dict["summary"] = summary
+        if no_flow_overlap is not UNSET:
+            field_dict["no_flow_overlap"] = no_flow_overlap
+        if tag is not UNSET:
+            field_dict["tag"] = tag
 
         return field_dict
 
@@ -151,6 +175,7 @@ class ListSchedulesResponse200Item:
         from ..models.list_schedules_response_200_item_on_recovery_extra_args import (
             ListSchedulesResponse200ItemOnRecoveryExtraArgs,
         )
+        from ..models.list_schedules_response_200_item_retry import ListSchedulesResponse200ItemRetry
 
         d = src_dict.copy()
         path = d.pop("path")
@@ -208,6 +233,19 @@ class ListSchedulesResponse200Item:
 
         ws_error_handler_muted = d.pop("ws_error_handler_muted", UNSET)
 
+        _retry = d.pop("retry", UNSET)
+        retry: Union[Unset, ListSchedulesResponse200ItemRetry]
+        if isinstance(_retry, Unset):
+            retry = UNSET
+        else:
+            retry = ListSchedulesResponse200ItemRetry.from_dict(_retry)
+
+        summary = d.pop("summary", UNSET)
+
+        no_flow_overlap = d.pop("no_flow_overlap", UNSET)
+
+        tag = d.pop("tag", UNSET)
+
         list_schedules_response_200_item = cls(
             path=path,
             edited_by=edited_by,
@@ -229,6 +267,10 @@ class ListSchedulesResponse200Item:
             on_recovery_times=on_recovery_times,
             on_recovery_extra_args=on_recovery_extra_args,
             ws_error_handler_muted=ws_error_handler_muted,
+            retry=retry,
+            summary=summary,
+            no_flow_overlap=no_flow_overlap,
+            tag=tag,
         )
 
         list_schedules_response_200_item.additional_properties = d
