@@ -21,6 +21,7 @@ if TYPE_CHECKING:
     from ..models.list_schedules_with_jobs_response_200_item_on_recovery_extra_args import (
         ListSchedulesWithJobsResponse200ItemOnRecoveryExtraArgs,
     )
+    from ..models.list_schedules_with_jobs_response_200_item_retry import ListSchedulesWithJobsResponse200ItemRetry
 
 
 T = TypeVar("T", bound="ListSchedulesWithJobsResponse200Item")
@@ -50,6 +51,10 @@ class ListSchedulesWithJobsResponse200Item:
         on_recovery_times (Union[Unset, float]):
         on_recovery_extra_args (Union[Unset, ListSchedulesWithJobsResponse200ItemOnRecoveryExtraArgs]):
         ws_error_handler_muted (Union[Unset, bool]):
+        retry (Union[Unset, ListSchedulesWithJobsResponse200ItemRetry]):
+        summary (Union[Unset, str]):
+        no_flow_overlap (Union[Unset, bool]):
+        tag (Union[Unset, str]):
         jobs (Union[Unset, List['ListSchedulesWithJobsResponse200ItemJobsItem']]):
     """
 
@@ -73,6 +78,10 @@ class ListSchedulesWithJobsResponse200Item:
     on_recovery_times: Union[Unset, float] = UNSET
     on_recovery_extra_args: Union[Unset, "ListSchedulesWithJobsResponse200ItemOnRecoveryExtraArgs"] = UNSET
     ws_error_handler_muted: Union[Unset, bool] = UNSET
+    retry: Union[Unset, "ListSchedulesWithJobsResponse200ItemRetry"] = UNSET
+    summary: Union[Unset, str] = UNSET
+    no_flow_overlap: Union[Unset, bool] = UNSET
+    tag: Union[Unset, str] = UNSET
     jobs: Union[Unset, List["ListSchedulesWithJobsResponse200ItemJobsItem"]] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
@@ -108,6 +117,13 @@ class ListSchedulesWithJobsResponse200Item:
             on_recovery_extra_args = self.on_recovery_extra_args.to_dict()
 
         ws_error_handler_muted = self.ws_error_handler_muted
+        retry: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.retry, Unset):
+            retry = self.retry.to_dict()
+
+        summary = self.summary
+        no_flow_overlap = self.no_flow_overlap
+        tag = self.tag
         jobs: Union[Unset, List[Dict[str, Any]]] = UNSET
         if not isinstance(self.jobs, Unset):
             jobs = []
@@ -152,6 +168,14 @@ class ListSchedulesWithJobsResponse200Item:
             field_dict["on_recovery_extra_args"] = on_recovery_extra_args
         if ws_error_handler_muted is not UNSET:
             field_dict["ws_error_handler_muted"] = ws_error_handler_muted
+        if retry is not UNSET:
+            field_dict["retry"] = retry
+        if summary is not UNSET:
+            field_dict["summary"] = summary
+        if no_flow_overlap is not UNSET:
+            field_dict["no_flow_overlap"] = no_flow_overlap
+        if tag is not UNSET:
+            field_dict["tag"] = tag
         if jobs is not UNSET:
             field_dict["jobs"] = jobs
 
@@ -172,6 +196,7 @@ class ListSchedulesWithJobsResponse200Item:
         from ..models.list_schedules_with_jobs_response_200_item_on_recovery_extra_args import (
             ListSchedulesWithJobsResponse200ItemOnRecoveryExtraArgs,
         )
+        from ..models.list_schedules_with_jobs_response_200_item_retry import ListSchedulesWithJobsResponse200ItemRetry
 
         d = src_dict.copy()
         path = d.pop("path")
@@ -233,6 +258,19 @@ class ListSchedulesWithJobsResponse200Item:
 
         ws_error_handler_muted = d.pop("ws_error_handler_muted", UNSET)
 
+        _retry = d.pop("retry", UNSET)
+        retry: Union[Unset, ListSchedulesWithJobsResponse200ItemRetry]
+        if isinstance(_retry, Unset):
+            retry = UNSET
+        else:
+            retry = ListSchedulesWithJobsResponse200ItemRetry.from_dict(_retry)
+
+        summary = d.pop("summary", UNSET)
+
+        no_flow_overlap = d.pop("no_flow_overlap", UNSET)
+
+        tag = d.pop("tag", UNSET)
+
         jobs = []
         _jobs = d.pop("jobs", UNSET)
         for jobs_item_data in _jobs or []:
@@ -261,6 +299,10 @@ class ListSchedulesWithJobsResponse200Item:
             on_recovery_times=on_recovery_times,
             on_recovery_extra_args=on_recovery_extra_args,
             ws_error_handler_muted=ws_error_handler_muted,
+            retry=retry,
+            summary=summary,
+            no_flow_overlap=no_flow_overlap,
+            tag=tag,
             jobs=jobs,
         )
 
