@@ -21,6 +21,7 @@ class ListUsersAsSuperAdminResponse200Item:
         verified (bool):
         name (Union[Unset, str]):
         company (Union[Unset, str]):
+        username (Union[Unset, str]):
     """
 
     email: str
@@ -29,6 +30,7 @@ class ListUsersAsSuperAdminResponse200Item:
     verified: bool
     name: Union[Unset, str] = UNSET
     company: Union[Unset, str] = UNSET
+    username: Union[Unset, str] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -39,6 +41,7 @@ class ListUsersAsSuperAdminResponse200Item:
         verified = self.verified
         name = self.name
         company = self.company
+        username = self.username
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
@@ -54,6 +57,8 @@ class ListUsersAsSuperAdminResponse200Item:
             field_dict["name"] = name
         if company is not UNSET:
             field_dict["company"] = company
+        if username is not UNSET:
+            field_dict["username"] = username
 
         return field_dict
 
@@ -72,6 +77,8 @@ class ListUsersAsSuperAdminResponse200Item:
 
         company = d.pop("company", UNSET)
 
+        username = d.pop("username", UNSET)
+
         list_users_as_super_admin_response_200_item = cls(
             email=email,
             login_type=login_type,
@@ -79,6 +86,7 @@ class ListUsersAsSuperAdminResponse200Item:
             verified=verified,
             name=name,
             company=company,
+            username=username,
         )
 
         list_users_as_super_admin_response_200_item.additional_properties = d
