@@ -2,14 +2,19 @@ from enum import Enum
 
 
 class RawScriptLanguage(str, Enum):
-    DENO = "deno"
-    PYTHON3 = "python3"
-    GO = "go"
     BASH = "bash"
-    POSTGRESQL = "postgresql"
-    MYSQL = "mysql"
+    BIGQUERY = "bigquery"
+    BUN = "bun"
+    DENO = "deno"
+    GO = "go"
     GRAPHQL = "graphql"
+    MSSQL = "mssql"
+    MYSQL = "mysql"
     NATIVETS = "nativets"
+    POSTGRESQL = "postgresql"
+    POWERSHELL = "powershell"
+    PYTHON3 = "python3"
+    SNOWFLAKE = "snowflake"
 
     def __str__(self) -> str:
         return str(self.value)
