@@ -1,56 +1,76 @@
-from typing import Any, Dict, List, Type, TypeVar, Union
+from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union
 
-import attr
+from attrs import define as _attrs_define
+from attrs import field as _attrs_field
 
-from ..models.run_flow_preview_json_body_value_failure_module_mock import RunFlowPreviewJsonBodyValueFailureModuleMock
-from ..models.run_flow_preview_json_body_value_failure_module_retry import RunFlowPreviewJsonBodyValueFailureModuleRetry
-from ..models.run_flow_preview_json_body_value_failure_module_sleep_type_0 import (
-    RunFlowPreviewJsonBodyValueFailureModuleSleepType0,
-)
-from ..models.run_flow_preview_json_body_value_failure_module_sleep_type_1 import (
-    RunFlowPreviewJsonBodyValueFailureModuleSleepType1,
-)
-from ..models.run_flow_preview_json_body_value_failure_module_stop_after_if import (
-    RunFlowPreviewJsonBodyValueFailureModuleStopAfterIf,
-)
-from ..models.run_flow_preview_json_body_value_failure_module_suspend import (
-    RunFlowPreviewJsonBodyValueFailureModuleSuspend,
-)
 from ..types import UNSET, Unset
 
+if TYPE_CHECKING:
+    from ..models.run_flow_preview_json_body_value_failure_module_mock import (
+        RunFlowPreviewJsonBodyValueFailureModuleMock,
+    )
+    from ..models.run_flow_preview_json_body_value_failure_module_retry import (
+        RunFlowPreviewJsonBodyValueFailureModuleRetry,
+    )
+    from ..models.run_flow_preview_json_body_value_failure_module_sleep_type_0 import (
+        RunFlowPreviewJsonBodyValueFailureModuleSleepType0,
+    )
+    from ..models.run_flow_preview_json_body_value_failure_module_sleep_type_1 import (
+        RunFlowPreviewJsonBodyValueFailureModuleSleepType1,
+    )
+    from ..models.run_flow_preview_json_body_value_failure_module_stop_after_if import (
+        RunFlowPreviewJsonBodyValueFailureModuleStopAfterIf,
+    )
+    from ..models.run_flow_preview_json_body_value_failure_module_suspend import (
+        RunFlowPreviewJsonBodyValueFailureModuleSuspend,
+    )
+
+
 T = TypeVar("T", bound="RunFlowPreviewJsonBodyValueFailureModule")
 
 
-@attr.s(auto_attribs=True)
+@_attrs_define
 class RunFlowPreviewJsonBodyValueFailureModule:
     """
     Attributes:
         id (str):
         value (Any):
         stop_after_if (Union[Unset, RunFlowPreviewJsonBodyValueFailureModuleStopAfterIf]):
-        sleep (Union[RunFlowPreviewJsonBodyValueFailureModuleSleepType0,
-            RunFlowPreviewJsonBodyValueFailureModuleSleepType1, Unset]):
+        sleep (Union['RunFlowPreviewJsonBodyValueFailureModuleSleepType0',
+            'RunFlowPreviewJsonBodyValueFailureModuleSleepType1', Unset]):
         cache_ttl (Union[Unset, float]):
+        timeout (Union[Unset, float]):
+        delete_after_use (Union[Unset, bool]):
         summary (Union[Unset, str]):
         mock (Union[Unset, RunFlowPreviewJsonBodyValueFailureModuleMock]):
         suspend (Union[Unset, RunFlowPreviewJsonBodyValueFailureModuleSuspend]):
+        priority (Union[Unset, float]):
         retry (Union[Unset, RunFlowPreviewJsonBodyValueFailureModuleRetry]):
     """
 
     id: str
     value: Any
-    stop_after_if: Union[Unset, RunFlowPreviewJsonBodyValueFailureModuleStopAfterIf] = UNSET
+    stop_after_if: Union[Unset, "RunFlowPreviewJsonBodyValueFailureModuleStopAfterIf"] = UNSET
     sleep: Union[
-        RunFlowPreviewJsonBodyValueFailureModuleSleepType0, RunFlowPreviewJsonBodyValueFailureModuleSleepType1, Unset
+        "RunFlowPreviewJsonBodyValueFailureModuleSleepType0",
+        "RunFlowPreviewJsonBodyValueFailureModuleSleepType1",
+        Unset,
     ] = UNSET
     cache_ttl: Union[Unset, float] = UNSET
+    timeout: Union[Unset, float] = UNSET
+    delete_after_use: Union[Unset, bool] = UNSET
     summary: Union[Unset, str] = UNSET
-    mock: Union[Unset, RunFlowPreviewJsonBodyValueFailureModuleMock] = UNSET
-    suspend: Union[Unset, RunFlowPreviewJsonBodyValueFailureModuleSuspend] = UNSET
-    retry: Union[Unset, RunFlowPreviewJsonBodyValueFailureModuleRetry] = UNSET
-    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
+    mock: Union[Unset, "RunFlowPreviewJsonBodyValueFailureModuleMock"] = UNSET
+    suspend: Union[Unset, "RunFlowPreviewJsonBodyValueFailureModuleSuspend"] = UNSET
+    priority: Union[Unset, float] = UNSET
+    retry: Union[Unset, "RunFlowPreviewJsonBodyValueFailureModuleRetry"] = UNSET
+    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
+        from ..models.run_flow_preview_json_body_value_failure_module_sleep_type_0 import (
+            RunFlowPreviewJsonBodyValueFailureModuleSleepType0,
+        )
+
         id = self.id
         value = self.value
         stop_after_if: Union[Unset, Dict[str, Any]] = UNSET
@@ -72,6 +92,8 @@ class RunFlowPreviewJsonBodyValueFailureModule:
                 sleep = self.sleep.to_dict()
 
         cache_ttl = self.cache_ttl
+        timeout = self.timeout
+        delete_after_use = self.delete_after_use
         summary = self.summary
         mock: Union[Unset, Dict[str, Any]] = UNSET
         if not isinstance(self.mock, Unset):
@@ -81,6 +103,7 @@ class RunFlowPreviewJsonBodyValueFailureModule:
         if not isinstance(self.suspend, Unset):
             suspend = self.suspend.to_dict()
 
+        priority = self.priority
         retry: Union[Unset, Dict[str, Any]] = UNSET
         if not isinstance(self.retry, Unset):
             retry = self.retry.to_dict()
@@ -99,12 +122,18 @@ class RunFlowPreviewJsonBodyValueFailureModule:
             field_dict["sleep"] = sleep
         if cache_ttl is not UNSET:
             field_dict["cache_ttl"] = cache_ttl
+        if timeout is not UNSET:
+            field_dict["timeout"] = timeout
+        if delete_after_use is not UNSET:
+            field_dict["delete_after_use"] = delete_after_use
         if summary is not UNSET:
             field_dict["summary"] = summary
         if mock is not UNSET:
             field_dict["mock"] = mock
         if suspend is not UNSET:
             field_dict["suspend"] = suspend
+        if priority is not UNSET:
+            field_dict["priority"] = priority
         if retry is not UNSET:
             field_dict["retry"] = retry
 
@@ -112,6 +141,25 @@ class RunFlowPreviewJsonBodyValueFailureModule:
 
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+        from ..models.run_flow_preview_json_body_value_failure_module_mock import (
+            RunFlowPreviewJsonBodyValueFailureModuleMock,
+        )
+        from ..models.run_flow_preview_json_body_value_failure_module_retry import (
+            RunFlowPreviewJsonBodyValueFailureModuleRetry,
+        )
+        from ..models.run_flow_preview_json_body_value_failure_module_sleep_type_0 import (
+            RunFlowPreviewJsonBodyValueFailureModuleSleepType0,
+        )
+        from ..models.run_flow_preview_json_body_value_failure_module_sleep_type_1 import (
+            RunFlowPreviewJsonBodyValueFailureModuleSleepType1,
+        )
+        from ..models.run_flow_preview_json_body_value_failure_module_stop_after_if import (
+            RunFlowPreviewJsonBodyValueFailureModuleStopAfterIf,
+        )
+        from ..models.run_flow_preview_json_body_value_failure_module_suspend import (
+            RunFlowPreviewJsonBodyValueFailureModuleSuspend,
+        )
+
         d = src_dict.copy()
         id = d.pop("id")
 
@@ -127,8 +175,8 @@ class RunFlowPreviewJsonBodyValueFailureModule:
         def _parse_sleep(
             data: object,
         ) -> Union[
-            RunFlowPreviewJsonBodyValueFailureModuleSleepType0,
-            RunFlowPreviewJsonBodyValueFailureModuleSleepType1,
+            "RunFlowPreviewJsonBodyValueFailureModuleSleepType0",
+            "RunFlowPreviewJsonBodyValueFailureModuleSleepType1",
             Unset,
         ]:
             if isinstance(data, Unset):
@@ -161,6 +209,10 @@ class RunFlowPreviewJsonBodyValueFailureModule:
 
         cache_ttl = d.pop("cache_ttl", UNSET)
 
+        timeout = d.pop("timeout", UNSET)
+
+        delete_after_use = d.pop("delete_after_use", UNSET)
+
         summary = d.pop("summary", UNSET)
 
         _mock = d.pop("mock", UNSET)
@@ -177,6 +229,8 @@ class RunFlowPreviewJsonBodyValueFailureModule:
         else:
             suspend = RunFlowPreviewJsonBodyValueFailureModuleSuspend.from_dict(_suspend)
 
+        priority = d.pop("priority", UNSET)
+
         _retry = d.pop("retry", UNSET)
         retry: Union[Unset, RunFlowPreviewJsonBodyValueFailureModuleRetry]
         if isinstance(_retry, Unset):
@@ -190,9 +244,12 @@ class RunFlowPreviewJsonBodyValueFailureModule:
             stop_after_if=stop_after_if,
             sleep=sleep,
             cache_ttl=cache_ttl,
+            timeout=timeout,
+            delete_after_use=delete_after_use,
             summary=summary,
             mock=mock,
             suspend=suspend,
+            priority=priority,
             retry=retry,
         )
 
