@@ -1,7 +1,8 @@
 import datetime
-from typing import Any, Dict, List, Type, TypeVar, Union
+from typing import Any, Dict, List, Type, TypeVar, Union, cast
 
-import attr
+from attrs import define as _attrs_define
+from attrs import field as _attrs_field
 from dateutil.parser import isoparse
 
 from ..types import UNSET, Unset
@@ -9,7 +10,7 @@ from ..types import UNSET, Unset
 T = TypeVar("T", bound="WorkerPing")
 
 
-@attr.s(auto_attribs=True)
+@_attrs_define
 class WorkerPing:
     """
     Attributes:
@@ -18,7 +19,10 @@ class WorkerPing:
         started_at (datetime.datetime):
         ip (str):
         jobs_executed (int):
+        worker_group (str):
+        wm_version (str):
         last_ping (Union[Unset, float]):
+        custom_tags (Union[Unset, List[str]]):
     """
 
     worker: str
@@ -26,8 +30,11 @@ class WorkerPing:
     started_at: datetime.datetime
     ip: str
     jobs_executed: int
+    worker_group: str
+    wm_version: str
     last_ping: Union[Unset, float] = UNSET
-    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
+    custom_tags: Union[Unset, List[str]] = UNSET
+    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
         worker = self.worker
@@ -36,7 +43,12 @@ class WorkerPing:
 
         ip = self.ip
         jobs_executed = self.jobs_executed
+        worker_group = self.worker_group
+        wm_version = self.wm_version
         last_ping = self.last_ping
+        custom_tags: Union[Unset, List[str]] = UNSET
+        if not isinstance(self.custom_tags, Unset):
+            custom_tags = self.custom_tags
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
@@ -47,10 +59,14 @@ class WorkerPing:
                 "started_at": started_at,
                 "ip": ip,
                 "jobs_executed": jobs_executed,
+                "worker_group": worker_group,
+                "wm_version": wm_version,
             }
         )
         if last_ping is not UNSET:
             field_dict["last_ping"] = last_ping
+        if custom_tags is not UNSET:
+            field_dict["custom_tags"] = custom_tags
 
         return field_dict
 
@@ -67,15 +83,24 @@ class WorkerPing:
 
         jobs_executed = d.pop("jobs_executed")
 
+        worker_group = d.pop("worker_group")
+
+        wm_version = d.pop("wm_version")
+
         last_ping = d.pop("last_ping", UNSET)
 
+        custom_tags = cast(List[str], d.pop("custom_tags", UNSET))
+
         worker_ping = cls(
             worker=worker,
             worker_instance=worker_instance,
             started_at=started_at,
             ip=ip,
             jobs_executed=jobs_executed,
+            worker_group=worker_group,
+            wm_version=wm_version,
             last_ping=last_ping,
+            custom_tags=custom_tags,
         )
 
         worker_ping.additional_properties = d
